/*
 * Copyright (c) 2014 David Cooke. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 */



package gamefx2.gpl;

/**
 * Select simple methods replacing ones in com.sun.javafx.Utils and
 * com.sun.javafx.PlatformUtil which were (re-)moved in later patches.
 * 
 * @version $Revision: 1.1 $
 * @author  David Cooke
 */
public class Utils
{
    /**
     * Operating system name from properties.
     */
    private static final String osC = System.getProperty("os.name");
    
    /**
     * Flag indicating operating system is a Mac.
     */
    private static final boolean macC = osC.startsWith("Mac");
    
    
    
    /**
     * Simple utility function which clamps the given value to be strictly
     * between the min and max values.
     * 
     * @param min	the minimum value for the result
     * @param value	the value to clamp
     * @param max	the maximum value for the result
     * @return		the clamped value
     */
    public static double clamp(double min, double value, double max)
    {
	return Math.max(min, Math.min(value, max));
    }
    
    
    
    /**
     * Returns true if the operating system is a form of Mac OS.
     * 
     * @return		<code>true</code> if it is 
     */
    public static boolean isMac()
    {
        return macC;
    }
}
